//Read PPM from one channel and use to switch to NavLights on
//Positon 1 is Nav Lights on.  Position 2 is Nav lights and landing lights
//Read PPM from second channel and control gear door and then lower gear
//Note Light 1 and 2 are out of sequence so it looks cooler.

int LightSwitch = 2;  //Position 1 turns on Nav Lights, 2 turns on Landing lights.  Rc channel 8
unsigned int LightSwitchValue;
long currentTime = 0;
boolean lightsOn = false;

//Steady Lights
int LandingLight = 4;  //White Turns on with second switch
int portNavLight = 5;  //Red constant on
int starboardNavLight = 6; //Green constand on

//Revolving Light 
boolean RevolvingLightSwitch = true;//Set to false if not using this feature
int RevolvingLight = 3;  //Replicates revolving light  (analog)
int RevolvingLighteInterval = 0;
int RevolvingLightDirection = HIGH;

//White Strobe 1
boolean WhiteStrobeSwitch1 = true;//Set to false if not using this feature
int WhiteStrobe1 = 7; //Flashes twice fast every second
long whiteStrobeTimer1 = millis();
long whiteStrobeInterval1 = 2000;
int whiteStrobePhase1 = 1;


//White Strobe 2
boolean WhiteStrobeSwitch2 = true;//Set to false if not using this feature
int WhiteStrobe2 = 8; //Flashes twice fast every second
long whiteStrobeTimer2 = millis();
long whiteStrobeInterval2 = 2100;
int whiteStrobePhase2 = 1;

//Fast Strobe
boolean FastStrobeSwitch = true;  //Set to false if not using this feature
int FastStrobe = 9; //Flashes fast
int FastStrobeState = LOW;
long fastStrobeInterval = 150;
long fastStrobeTimer = millis();

//On Arduino LED
int ledPin = 13;
int ledState = LOW;

//Debugging here
boolean debug = false;  //turn on to see debug messages in serial monitor


void setup()
{
  Serial.begin(115200);

  currentTime = millis();
  pinMode(LandingLight, OUTPUT); 
  pinMode(portNavLight, OUTPUT);
  pinMode(starboardNavLight, OUTPUT);
  pinMode(WhiteStrobe1, OUTPUT);
  pinMode(WhiteStrobe2, OUTPUT);
  pinMode(FastStrobe, OUTPUT);
  pinMode(RevolvingLight, OUTPUT);
  pinMode(LightSwitch, INPUT);
  NavLightsOff();
  LandingLightsOff();
  pinMode(ledPin, OUTPUT);
}

void NavLightsOn()
{
  lightsOn = true;
  digitalWrite(portNavLight, HIGH);
  digitalWrite(starboardNavLight, HIGH);
}
void NavLightsOff()
{
  lightsOn= false;
  digitalWrite(portNavLight, LOW);
  digitalWrite(starboardNavLight, LOW);
  digitalWrite(WhiteStrobe1, LOW);
  digitalWrite(WhiteStrobe2, LOW);
  digitalWrite(FastStrobe, LOW);
  digitalWrite(RevolvingLight, LOW);
}
void LandingLightsOn()
{
  digitalWrite(LandingLight, HIGH);
}
void LandingLightsOff()
{
  digitalWrite(LandingLight, LOW);
}
void pulse()
{
  LightSwitchValue = pulseIn(LightSwitch, HIGH, 20000); //times out in 20000 uS
  //  LandingGearSwitchValue = pulseIn(LandingGearSwitch, HIGH, 20000) //times out in 20000 uS
  //Adjust these values for your receiver
  if (LightSwitchValue > 1700)  //switch is off or error
  { 
    NavLightsOff();
    LandingLightsOff();
    if (debug)
      Serial.println("All lights off");
  }
  if (LightSwitchValue < 1700) //Nav lights are on
  {
    NavLightsOn();
    LandingLightsOff();
    if (debug)
      Serial.println("Nav Lights on");
  }
  if (LightSwitchValue < 1400) //landing lights are on
  {
    LandingLightsOn();
    if (debug)
      Serial.println("Landing Lights On");
  }
  if (LightSwitchValue < 900) //must be an error
  { 
    NavLightsOff();
    LandingLightsOff();
    if (debug)
      Serial.println("All lights off");
  }

}

void loop()
{

  pulse();  //Check Radio Receiver position.
  currentTime = millis();
  if (lightsOn )
  {
    //revolving light 1
    if (RevolvingLightSwitch)
    {
      analogWrite(RevolvingLight, RevolvingLighteInterval);
      if (RevolvingLightDirection == HIGH)
        RevolvingLighteInterval = RevolvingLighteInterval + 5;
      else
        RevolvingLighteInterval = RevolvingLighteInterval - 5;
      if (RevolvingLighteInterval > 180 && RevolvingLightDirection == HIGH )
        RevolvingLighteInterval = 255; //Jump for the flash
      if (RevolvingLighteInterval > 220 && RevolvingLightDirection == LOW )
        RevolvingLighteInterval = 180; //Dump from the flash
   
      if (RevolvingLighteInterval == 255)
        RevolvingLightDirection = LOW;
      if (RevolvingLighteInterval == 0)
        RevolvingLightDirection = HIGH;
      if (debug)
      {
        Serial.print("Revolving Light value: ");
        Serial.println(RevolvingLighteInterval);
      }
    }   

    //White Strobe 1
    if(currentTime-whiteStrobeTimer1 > whiteStrobeInterval1 && WhiteStrobeSwitch1)
    {
      switch(whiteStrobePhase1)
      {
      case 1:
        //strobe on first 
        digitalWrite(WhiteStrobe1, HIGH);
        if (debug)
          Serial.println("White Strobe 1 on");
        whiteStrobeInterval1=50;
        whiteStrobePhase1 = 2;
        break;
      case 2:
        //strobe off first cycle
        digitalWrite(WhiteStrobe1, LOW);
        if (debug)
          Serial.println("White Strobe 1 off");            
        whiteStrobeInterval1=1000;
        whiteStrobePhase1 = 3;
        break;
      case 3:
        //strobe on second cycle
        digitalWrite(WhiteStrobe1, HIGH);
        if (debug)
          Serial.println("White Strobe 1 on");            
        whiteStrobeInterval1=50;
        whiteStrobePhase1 = 4;
        break;
      case 4:
        //strobe off second cycle
        digitalWrite(WhiteStrobe1, LOW);
        if (debug)
          Serial.println("White Strobe 1 off");            
        whiteStrobeInterval1=2000;
        whiteStrobePhase1 = 1;
        break;
      }
      whiteStrobeTimer1=millis();
    } 

    //White Strobe 2
    if(currentTime-whiteStrobeTimer2 > whiteStrobeInterval2 && WhiteStrobeSwitch2)
    {
      switch(whiteStrobePhase2)
      {
      case 1:
        //strobe on first 
        digitalWrite(WhiteStrobe2, HIGH);
        if (debug)
          Serial.println("White Strobe 2 on");
        whiteStrobeInterval2=50;
        whiteStrobePhase2 = 2;
        break;
      case 2:
        //strobe off first cycle
        digitalWrite(WhiteStrobe2, LOW);
        if (debug)
          Serial.println("White Strobe 2 off");            
        whiteStrobeInterval2=1010;
        whiteStrobePhase2 = 3;
        break;
      case 3:
        //strobe on second cycle
        digitalWrite(WhiteStrobe2, HIGH);
        if (debug)
          Serial.println("White Strobe 2 on");            
        whiteStrobeInterval2=50;
        whiteStrobePhase2 = 4;
        break;
      case 4:
        //strobe off second cycle
        digitalWrite(WhiteStrobe2, LOW);
        if (debug)
          Serial.println("White Strobe 2 off");            
        whiteStrobeInterval2=2300;
        whiteStrobePhase2 = 1;
        break;
      }
      whiteStrobeTimer2=millis();
    }

    //Fast Strobe

    if(currentTime-fastStrobeTimer > fastStrobeInterval && FastStrobeSwitch)
    {
      if (FastStrobeState == LOW)
        FastStrobeState = HIGH;
      else
        FastStrobeState = LOW;
      digitalWrite(FastStrobe, FastStrobeState);

      fastStrobeTimer=millis();
    }
    //This is just here to see if Arduino locked up or is running slow
    if (ledState == LOW)
      ledState = HIGH;
    else
      ledState = LOW;
    // set the LED with the ledState of the variable:
    digitalWrite(ledPin, ledState);      



  }//if lights on

} //Loop















